@@ -1,12 +1,16 @@
+from __future__ import annotations
 from abc import abstractmethod
-from ...utils import Table
+from typing import TYPE_CHECKING
 
+if TYPE_CHECKING:
+    from ormlambda import Table
+    from ormlambda import IRepositoryBase
+
+from ormlambda.common.abstract_classes import NonQueryBase
 from .IInsert import IInsert
-from ...common.interfaces import IRepositoryBase
-from ...common.abstract_classes import NonQueryBase
 
 
-class InsertQueryBase[T: Table, TRepo: IRepositoryBase](NonQueryBase[T, IRepositoryBase], IInsert[T]):
+class InsertQueryBase[T: Table, TRepo: IRepositoryBase](NonQueryBase[T, TRepo], IInsert[T]):
     def __init__(self, model: T, repository: TRepo) -> None:
         super().__init__(model, repository)
 
